CustomTableRow class

Constructors

CustomTableRow({required dynamic item, required List<Widget> widgets, bool? selected, Color? backgroundColor})

Properties

backgroundColor Color?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
item ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool?
getter/setter pair
widgets List<Widget>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited