InputDictKey enum

Inheritance
Available extensions

Values

inputRequired → const InputDictKey
formatError → const InputDictKey
invalidEmail → const InputDictKey
textTooShort → const InputDictKey
textTooLong → const InputDictKey
floatTooHigh → const InputDictKey
floatTooLow → const InputDictKey
floatTooManyDecimals → const InputDictKey
invalidFloat → const InputDictKey
dateTooEarly → const InputDictKey
dateTooLate → const InputDictKey
invalidDate → const InputDictKey
integerTooLow → const InputDictKey
integerTooHigh → const InputDictKey
invalidInteger → const InputDictKey
invalidSiren → const InputDictKey

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InputDictKey>
A constant List of the values in this enum, in order of their declaration.