OwlnextDigitVerifCodeStyle class

Styling class

Constructors

OwlnextDigitVerifCodeStyle({EdgeInsetsGeometry? contentPadding, Color? textColor, Color? fillColor, Color? borderColor, Color? focusedBorderColor, Color? deleteIconColor, double? borderRadius, double? borderWidth, double? inputWidth, double? controllersSpacing})
const

Properties

borderColor Color?
Border color of input fields
final
borderRadius double?
Border radius of input fields
final
borderWidth double?
Border width of input fields
final
contentPadding EdgeInsetsGeometry?
Padding inside each input field
final
controllersSpacing double?
Spacing between input fields
final
deleteIconColor Color?
Color of the delete icon
final
fillColor Color?
Fill color of input fields
final
focusedBorderColor Color?
Border color when input field is focused
final
hashCode int
The hash code for this object.
no setterinherited
inputWidth double?
Width of each input field
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color?
Text color inside input fields
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited