OwlnextSelectMultiple class

Inheritance

Constructors

OwlnextSelectMultiple({Key? key, required List<String>? values, required void onChanged(List<String> newValues), List<DropdownMenuItem<String>>? items, String? label, bool? enabled = true, bool? isMandatory = false, Function? infoCallback, Future<List<DropdownMenuItem<String>>> optionsRoute()?, Axis? axis = Axis.vertical})
Owlnext form input Based on Material design and uses DropdownButtonFormField Used to automate all selects behaviors ine one place
const

Properties

axis Axis?
Set the axis for the label -> input
final
enabled bool?
Is enabled or not
final
hashCode int
The hash code for this object.
no setterinherited
infoCallback Function?
Called when clicking on the information icon, right to the label Can be anything (openPanel, openPopup...)
final
isMandatory bool?
Is mandatory or not, determines the validator behavior
final
items List<DropdownMenuItem<String>>?
List of items to display Useful if you want to write the options without an API Response
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Select input label
final
onChanged → void Function(List<String> newValues)
Callback when a value is selected
final
optionsRoute Future<List<DropdownMenuItem<String>>> Function()?
Url to call in order to have the options Useful if you want your options list to be async
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>?
Current selected values in a list Displayed on top of the select for clarity
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<OwlnextSelectMultiple>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited