items property
List of items to display Useful if you want to write the options without an API Response
Implementation
final List<DropdownMenuItem<String>>? items;
List of items to display Useful if you want to write the options without an API Response
final List<DropdownMenuItem<String>>? items;