Custom autocomplete option model
Contains the option widget and value
The value is used to identify the option and is returned in the onSelect callback
The widget is the displayed part of the option, it can be any widget and is not limited to text
Custom checkbox option model
Contains the option widget and value
The value is used to identify the option and is returned in the handleChangeSelected callback
The widget is the displayed part of the option, it can be any widget and is
Custom radio option model
Contains the option widget and value
The value is used to identify the option and is returned in the handleChangeSelected callback
The widget is the displayed part of the option, it can be any widget and is not limited to text
FloatingNirrtiExample Widget Wrapper (in search of a better classname)
A simple NirrtiExamplePage wrapper which gives you access to it anywhere from your Flutter app code.
Class to define the constraints for date inputs in OwlnextInput
It includes minimum and maximum date constraints, as well as default input formatters for date, short date and hours inputs.
The class also includes assertions to ensure that the minimum date is before the maximum date, and provides default values for minimum and maximum dates if they are not specified.
Cosntraints for subtype amount (float) but historicaly called amount
It includes the maximum amount and the maximum number of decimals,
as well as default input formatters for amount inputs.
The class also provides a copyWith method to create a new instance with modified values,
and a static method to return default constraints with null values.
Cosntraints for subtype numbers (integer) but historicaly called numbers
It includes the minimum and maximum number, as well as default input formatters for integer inputs.
The class also includes assertions to ensure that the minimum number is before the maximum number,
and provides default values for minimum and maximum numbers if they are not specified.
Constraints for subtype text but historicaly called text
It includes the minimum and maximum number of characters, as well as default input formatters for text inputs.
The class also includes assertions to ensure that the minimum number of characters is less than or equal
to the number of characters limitation, and provides default values for minimum and maximum number of characters if they are not specified.
A custom label widget that displays a label with an optional mandatory asterisk.
The asterisk is displayed in a different color if the field is mandatory.
The widget uses a RichText to combine the label and the asterisk, allowing for different styling.
The label is the main text of the label, and its style can be customized with labelStyle.
The isMandatory flag determines whether the asterisk should be displayed, and the mandatoryAsterixColor allows for customizing the color of the asterisk. The [mandatoryChar
Custom side scroll section model
Represents a single section in the side scroll view
Contains the section name and widget to show when the section is active
The section name is used in the side menu to identify the section and can be any string
The section widget is the content displayed when the section is active