nirrti library

Classes

Artist
Singleton class Determines the styles to apply in every Nirrti Widget Has to be instanciated in the main() function of the Flutter app
AudioPlayer
AutocompleteOption
CustomAction
CustomButtonType
CustomCheckboxOption
CustomFilter
CustomRadioOption
CustomTableRow
ErrorType
FileUtils
FilterCall
OwlnextActionsButton
OwlnextAudioRecorder
OwlnextAutocomplete
OwlnextButton
OwlnextCheckbox
OwlnextDropzone
OwlnextHelper
OwlnextInput
OwlnextLoading
Show a custom loader on the screen Used to have the same behavior everywhere on the app Uses the theme primaryColor
OwlnextRadio
OwlnextSelect
OwlnextSelectMultiple
OwlnextSideScroll
OwlnextTable
OwlnextTapOutsideWrapper
Widget used to catch click and trigger an action callback when clicked on Often used to catch click outside of popup or modal in order to close it
WidgetSection

Enums

ButtonType
DropZoneSize
TextInputSubType
All subtypes of text input Determines the input's behavior on change and on form validation
TooltipType