nirrti library

Classes

Artist
Singleton class Determines the styles to apply in every Nirrti Widget Has to be instanciated in the main() function of the Flutter app
AutocompleteOption
Custom autocomplete option model Contains the option widget and value The value is used to identify the option and is returned in the onSelect callback The widget is the displayed part of the option, it can be any widget and is not limited to text
CustomAction
CustomButtonType
CustomCheckboxOption
Custom checkbox option model Contains the option widget and value The value is used to identify the option and is returned in the handleChangeSelected callback The widget is the displayed part of the option, it can be any widget and is
CustomFilter
CustomRadioOption
Custom radio option model Contains the option widget and value The value is used to identify the option and is returned in the handleChangeSelected callback The widget is the displayed part of the option, it can be any widget and is not limited to text
CustomTableRow
DateConstraints
DateInputLayoutModel
DateTimeDictionary
Fournit les libellés localisés pour chaque clé, avec possibilité d’overrides.
ErrorType
FilterCall
FloatingNirrtiExample
FloatingNirrtiExample Widget Wrapper (in search of a better classname) A simple NirrtiExamplePage wrapper which gives you access to it anywhere from your Flutter app code.
InputDictionnary
NirrtiExamplePage
NirrtiExamplePage page widget
OwlnextActionsButton
OwlnextAutocomplete
OwlnextButton
OwlnextCheckbox
OwlnextColorPicker
OwlnextContextualMenu
OwlnextCustomizableTable
OwlnextDate
OwlnextDigitVerifCode
OwlnextDigitVerifCodeStyle
Styling class
OwlnextFormWrapper
Form wrapper to manager error states on form fields Also deals with FocusTraversalPolicy for UX purposes
OwlnextInput
OwlnextListView
Use this widget to wrap your ListView Can be used with children or itemBuilder props Automatically manager ViewInsets for the virtual keyboards
OwlnextLoading
OwlnextMandatoryAsterixRichLabel
A custom label widget that displays a label with an optional mandatory asterisk. The asterisk is displayed in a different color if the field is mandatory. The widget uses a RichText to combine the label and the asterisk, allowing for different styling. The label is the main text of the label, and its style can be customized with labelStyle. The isMandatory flag determines whether the asterisk should be displayed, and the mandatoryAsterixColor allows for customizing the color of the asterisk. The [mandatoryChar
OwlnextPasswordCreator
OwlnextPortalMenu
OwlnextRadio
OwlnextSelect
OwlnextSelectMultiple
OwlnextSideScroll
OwlnextTab
OwlnextTabBehavior
OwlnextTabDecoration
OwlnextTable
OwlnextTapOutsideWrapper
Widget used to catch click and trigger an action callback when clicked on Often used to catch click outside of popup or modal in order to close it
OwlnextTime
PasswordCreationDictionnary
PortalMenuController
Permet d'ouvrir des menus d'overlays dans l'enfant qu'il controller mais est déclaré via les
PortalMenuSettings
ScrollBarStyling
Class responsible for passing styling properties to the ScrollBar
WidgetSection
Custom side scroll section model Represents a single section in the side scroll view Contains the section name and widget to show when the section is active The section name is used in the side menu to identify the section and can be any string The section widget is the content displayed when the section is active

Enums

ButtonType
DateTimeDictKey
Clés de traduction pour les messages de DateTimeValidator
InputDictKey
PasswordConditionsPosition
Enum that will define the password validity conditions position compared to password inputs
TextInputSubType
All subtypes of text input Determines the input's behavior on change and on form validation