OwlnextCheckboxDecoration class
Constructors
- OwlnextCheckboxDecoration({Color? color, BorderRadius? borderRadius, double? iconSize})
- OwlnextCheckboxDecoration.init({BuildContext? context})
Properties
- borderRadius ↔ BorderRadius?
-
getter/setter pair
- color ↔ Color?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Color? color, BorderRadius? borderRadius, double? iconSize}) → OwlnextCheckboxDecoration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited