OwlnextListView class
Use this widget to wrap your ListView
Can be used with children or itemBuilder props
Automatically manager ViewInsets for the virtual keyboards
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- OwlnextListView
Constructors
-
OwlnextListView({Key? key, Axis scrollDirection = Axis.vertical, ScrollController? scrollController, bool shrinkWrap = false, EdgeInsets? padding, int itemCount = 0, Widget? itemBuilder(BuildContext context, int index)?, double separatorSize = 8, Widget separatorBuilder(BuildContext context, int index)?, ScrollBarStyling? scrollbarStyle, ScrollPhysics physics = const BouncingScrollPhysics(), List<
Widget> children = const []}) -
const
Properties
-
children
→ List<
Widget> -
Children to display.
To use if you need different Widget to render
Cannot use with itemBuilder and itemCount props
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget? Function(BuildContext context, int index)?
-
To use if you need a list of the same Widget
Same as the ListView.builder method
final
- itemCount → int
-
To use if you used itemBuilder prop
Same as the ListView.builder method
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsets?
-
padding of the list view
final
- physics → ScrollPhysics
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollbarStyle → ScrollBarStyling?
-
overide scrollbar with custom theme
final
- scrollController → ScrollController?
-
ScrollController passed by the dev (to be flexible on scroll bahavior
dont forget to dispose it
final
- scrollDirection → Axis
-
Axis of the list. Defaults to Axis.vertical
final
- separatorBuilder → Widget Function(BuildContext context, int index)?
-
To use to build constom separator
Will be target only if itemBuilder props is provided
final
- separatorSize → double
-
Separator size override between elements in itemBuilder method
Defaults to 8
final
- shrinkWrap → bool
-
use shrinkwrap props on ListView constructor (using children)
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< OwlnextListView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited