optionsRoute property
Url to call in order to have the options Useful if you want your options list to be async
Implementation
final Future<List<DropdownMenuItem<String>>> Function()? optionsRoute;
Url to call in order to have the options Useful if you want your options list to be async
final Future<List<DropdownMenuItem<String>>> Function()? optionsRoute;