OwlnextTable class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- OwlnextTable
Constructors
-
OwlnextTable({Key? key, required List<
DataColumn> headersList, required List<CustomTableRow> rowsList, Future<bool> callback({int? pageNumber, String? search})?, bool hasSearch = true, Function? onClickRow, Function? button, bool isScrollable = true, required UniqueKey tableKey, bool hasCheckboxes = false, Widget? emptyState, double? headingRowHeight = 40, double? horizontalMargin = 0, Color? bottomBorderColor, bool? showHeaderWhenEmpty = true}) -
Owlnext Table component
Handles columns and rows, lazyloading, search and filters
const
Properties
- bottomBorderColor → Color?
-
final
-
Determines if the table has a top right button
Usually a "+" button to trigger a post callback
final
-
callback
→ Future<
bool> Function({int? pageNumber, String? search})? -
Callback function on search, filters clicks and lazyLoading
final
- emptyState → Widget?
-
Custom empty state Widget
final
- hasCheckboxes → bool
-
Determines if the table has checkboxes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSearch → bool
-
Determines if the table has a searchbar
final
-
headersList
→ List<
DataColumn> -
Headers to show in the table
final
- headingRowHeight → double?
-
final
- horizontalMargin → double?
-
final
- isScrollable → bool
-
Determines if the table has to be scrollable, or must have the same length as its childs
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClickRow → Function?
-
Callback on click row
final
-
rowsList
→ List<
CustomTableRow> -
Individual rows
Can have custom widgets list, but must have the same length as the headers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHeaderWhenEmpty → bool?
-
final
- tableKey → UniqueKey
-
Re-render table key
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< OwlnextTable> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited